@@ -5,4 +5,5 @@
 
 (unless (string= (with-open-file (s #p"version.lisp-expr") (read s))
                  (asdf:asdf-version))
-  (error "ASDF failed to upgrade itself"))
+  (format t "ASDF failed to upgrade itself")
+  (uiop:quit 1))
